@@ -3,8 +3,10 @@
 using namespace Rcpp;
 
 // [[Rcpp::export]]
-DictPtr R_hunspell_dict(Rcpp::String affix, CharacterVector dict){
+DictPtr R_hunspell_dict(Rcpp::String affix, CharacterVector dict, StringVector add_words){
   hunspell_dict *mydict = new hunspell_dict(affix, dict);
+  if(add_words.length())
+    mydict->add_words(add_words);
   return DictPtr(mydict);
 }
 
